@@ -5,7 +5,7 @@ from flask import Blueprint, redirect, url_for
 from textflow import auth
 from textflow.view.base import render_template
 
-view = Blueprint('index_view', __name__)
+view = Blueprint('index', __name__)
 
 
 @view.route('/', methods=('GET', 'POST'))
@@ -16,7 +16,7 @@ def index():
     """
     if auth.current_user.is_authenticated:
         # automatically login to project list page
-        return redirect(url_for('project_view.list_projects'))
+        return redirect(url_for('project.list_projects'))
     else:
 
         return render_template('index.html')
